ServiceProviderWrapper

Struct ServiceProviderWrapper 

pub struct ServiceProviderWrapper { /* private fields */ }

Implementations

Source

impl ServiceProviderWrapper

pub fn new(child: Arc<ServiceProvider>, root: Arc<ServiceProvider>) -> Arc<Self>

pub fn child(&self) -> &Arc<ServiceProvider>

pub fn root(&self) -> &Arc<ServiceProvider>

pub fn get<T: ?Sized + Send + Sync + 'static>(&self) -> Result<Arc<T>, RdiError>

pub fn get_optional<T: ?Sized + Send + Sync + 'static>(&self) -> Option<Arc<T>>

pub fn get_keyed<T: ?Sized + Send + Sync + 'static>( &self, key: &str, ) -> Result<Arc<T>, RdiError>

pub fn get_all<T: ?Sized + Send + Sync + 'static>(&self) -> Vec<Arc<T>>

pub fn get_named<T: Send + Sync + 'static>(&self, name: &str) -> Option<Arc<T>>

pub fn get_named_any(&self, name: &str) -> Option<Arc<dyn Any + Send + Sync>>

pub fn get_owned<T: Send + Sync + 'static>(&self) -> Result<T, RdiError>

Resolve owned T (bypass cache, fresh each call). Child-first, root-fallback. Returns Err if not registered or the service is Singleton.

pub fn try_get_owned<T: Send + Sync + 'static>(&self) -> Option<T>

Resolve owned T, returning None if not registered or Singleton.

pub fn get_keyed_owned<T: Send + Sync + 'static>( &self, key: &str, ) -> Result<T, RdiError>

Resolve owned keyed T. Child-first, root-fallback.

pub fn try_get_keyed_owned<T: Send + Sync + 'static>( &self, key: &str, ) -> Option<T>

Resolve owned keyed T, returning None if not found or Singleton.

pub async fn get_async<T: ?Sized + Send + Sync + 'static>( &self, ) -> Result<Arc<T>, RdiError>

Resolve an async service by type. Child-first, root-fallback.

pub async fn get_keyed_async<T: ?Sized + Send + Sync + 'static>( &self, key: &str, ) -> Result<Arc<T>, RdiError>

Resolve an async keyed service. Child-first, root-fallback.

Source

impl ServiceProviderWrapper

pub fn rdi_register_named( &self, name: &str, service: Arc<dyn Any + Send + Sync>, )

Register a named service (for IProvider trait).

pub fn rdi_remove_named(&self, name: &str)

Remove a named service (for IProvider trait).